==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervriendelijke pagina");
define("_FRIEND","Stuur dit verhaal naar een kennis");
define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ARTICLES","Artikelen");
define("_SUBMITNEWS","Nieuws inzenden");
define("_SUBMITADVICE","Vul het volgende formulier en controleer uw inzending goed.<br>Wij wijzen u erop dat niet alle inzendingen kunnen worden geplaatst.<br>Uw inzending wordt gecontroleerd op grammatica en kan bewerkt of ingekort worden.");
define("_SUBTITLE","Titel");
define("_BEDESCRIPTIVE","Gebruik korte, samengevatte tekst");
define("_BADTITLES","geen titels als:'Check This Out!' of 'Zie Dit!' e.d.");
define("_HTMLISFINE","HTML is toegstaan, maar controleer goed evt. URLs en HTML-tags!");
define("_AREYOUSURE","Heeft u de goede URL ingevuld, zonder tikfouten?");
define("_SUBPREVIEW","U moet het artikel n keer controleren (previewen), voordat U het kunt inzenden");
define("_SELECTTOPIC","Selecteer onderwerp");
define("_NEWSUBPREVIEW","Nieuws inzending preview");
define("_STORYLOOK","Uw inzending zal er zo uitzien:");
define("_CHECKSTORY","Controleer tekst, links, enz. voordat u uw verhaal verzendt!");
define("_THANKSSUB","Bedankt voor uw inzending!");
define("_SUBSENT","Uw inzending is ontvangen.");
define("_SUBTEXT","Uw inzending zal worden bekeken. Artikelen met incorrecte en beledigende 
define("_WEHAVESUB","Op dit ogenblik hebben wij");
define("_WAITING","inzendingen die op publicatie wachten.");
define("_PREVIEW","Preview");
define("_NEWUSER","Nieuwe gebruiker");
define("_USCORE","Score");
define("_DATE","Datum");
define("_STORYTEXT","Verhaaltekst");
define("_EXTENDEDTEXT","Verlengde tekst");
define("_LANGUAGE","Taal");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervriendelijke pagina");
define("_FRIEND","Stuur dit verhaal naar een kennis");
define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ARTICLES","Artikelen");
define("_SUBMITNEWS","Nieuws inzenden");
define("_SUBMITADVICE","Vul het volgende formulier en controleer uw inzending goed.<br>Wij wijzen u erop dat niet alle inzendingen kunnen worden geplaatst.<br>Uw inzending wordt gecontroleerd op grammatica en kan bewerkt of ingekort worden.");
define("_SUBTITLE","Titel");
define("_BEDESCRIPTIVE","Gebruik korte, samengevatte tekst");
define("_BADTITLES","geen titels als:'Check This Out!' of 'Zie Dit!' e.d.");
define("_HTMLISFINE","HTML is toegstaan, maar controleer goed evt. URLs en HTML-tags!");
define("_AREYOUSURE","Heeft u de goede URL ingevuld, zonder tikfouten?");
define("_SUBPREVIEW","U moet het artikel n keer controleren (previewen), voordat U het kunt inzenden");
define("_SELECTTOPIC","Selecteer onderwerp");
define("_NEWSUBPREVIEW","Nieuws inzending preview");
define("_STORYLOOK","Uw inzending zal er zo uitzien:");
define("_CHECKSTORY","Controleer tekst, links, enz. voordat u uw verhaal verzendt!");
define("_THANKSSUB","Bedankt voor uw inzending!");
define("_SUBSENT","Uw inzending is ontvangen.");
define("_SUBTEXT","Uw inzending zal worden bekeken. Artikelen met incorrecte en beledigende 
define("_WEHAVESUB","Op dit ogenblik hebben wij");
define("_WAITING","inzendingen die op publicatie wachten.");
define("_PREVIEW","Preview");
define("_NEWUSER","Nieuwe gebruiker");
define("_USCORE","Score");
define("_DATE","Datum");
define("_STORYTEXT","Verhaaltekst");
define("_EXTENDEDTEXT","Verlengde tekst");
define("_LANGUAGE","Taal");

define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
